@@ -6,7 +6,9 @@
  * Copyright (C) 1995 Olaf Kirch <okir@monad.swb.de>
  */
 
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 #include <sys/stat.h>
 #include <stdlib.h>
@@ -27,7 +29,7 @@ export_export(nfs_export *exp)
 	struct nfsctl_export	exparg;
 	struct nfsctl_client	cltarg;
 
-	if (!clp->m_exported) {
+	if (!clp->m_exported && (clp->m_type != MCL_GSS)) {
 		if (!cltsetup(&cltarg, clp))
 			return 0;
 		if (nfsaddclient(&cltarg) < 0)
