@@ -6,7 +6,9 @@
  * NSM for Linux.
  */
 
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 #include "statd.h"
 #include "notlist.h"
 
